@@ -1,4 +1,4 @@
-# (C) Copyright 2007-2021 Enthought, Inc., Austin, TX
+# (C) Copyright 2007-2022 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -38,6 +38,7 @@ extensions = [
     "sphinx.ext.intersphinx",
     "sphinx.ext.napoleon",
     "sphinx.ext.viewcode",
+    "sphinx_copybutton",
     "traits.util.trait_documenter",
 ]
 
@@ -52,7 +53,7 @@ master_doc = "index"
 
 # General substitutions.
 project = "envisage"
-copyright = "2008-2021, Enthought"
+copyright = "2007-2022, Enthought"
 
 # The default replacements for |version| and |release|, also used in various
 # other places throughout the built documents.
@@ -233,6 +234,6 @@ intersphinx_mapping = {
 
 extlinks = {
     'github-demo': (
-        'https://github.com/enthought/envisage/tree/master/envisage/examples/demo/%s',   # noqa: E501
+        f'https://github.com/enthought/envisage/tree/{version}/envisage/examples/demo/%s',   # noqa: E501
         '')
 }
