@@ -1,4 +1,4 @@
-# (C) Copyright 2007-2021 Enthought, Inc., Austin, TX
+# (C) Copyright 2007-2022 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -9,6 +9,7 @@
 # Thanks for using Enthought open source!
 """ The Envisage core plugin. """
 
+from contextlib import closing
 
 # Enthought library imports.
 from envisage.extension_point import ExtensionPoint
@@ -165,13 +166,9 @@ class CorePlugin(Plugin):
         # The resource manager is used to find the preferences files.
         resource_manager = ResourceManager()
         for resource_name in preferences:
-            f = resource_manager.file(resource_name)
-            try:
+            with closing(resource_manager.file(resource_name)) as f:
                 default.load(f)
 
-            finally:
-                f.close()
-
     def _register_service_offers(self, service_offers):
         """ Register a list of service offers. """
 
