@@ -5,7 +5,7 @@ from traits.api import Array, Interface, Str
 class IModel2d(Interface):
 
     # The user-visible name of the model.
-    name = Str
+    name = Str()
 
-    x_data = Array
-    y_data = Array
+    x_data = Array()
+    y_data = Array()
