@@ -1,4 +1,4 @@
-# (C) Copyright 2007-2021 Enthought, Inc., Austin, TX
+# (C) Copyright 2007-2022 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -19,12 +19,18 @@ import unittest
 from unittest import mock
 import warnings
 
+# Envisage is not currently compatible with ipykernel >= 6 or IPython >= 8. See
+# enthought/envisage#448.
 try:
-    import ipykernel  # noqa: F401
+    import ipykernel
+    import IPython
 except ImportError:
     ipykernel_available = False
 else:
-    ipykernel_available = True
+    ipykernel_available = (
+        ipykernel.version_info < (6,)
+        and IPython.version_info < (8,)
+    )
 
 if ipykernel_available:
     import ipykernel.iostream
@@ -38,6 +44,24 @@ if ipykernel_available:
     from envisage.plugins.ipython_kernel.api import InternalIPKernel
 
 
+# In rare cases, isinstance(obj, type) can raise. An example occurs in Python
+# 3.6 when obj has type `functools._lru_list_elem` and type is zmq.Socket. This
+# particular example is fixed in Python >= 3.7
+#
+# It may be possible to replace uses of safe_isinstance with plain old
+# isinstance once Python 3.6 support is no longer needed.
+# xref: enthought/envisage#469
+
+def safe_isinstance(obj, type):
+    """
+    Same as isinstance(obj, type), but suppresses AttributeError.
+    """
+    try:
+        return isinstance(obj, type)
+    except AttributeError:
+        return False
+
+
 @unittest.skipUnless(
     ipykernel_available, "skipping tests that require the ipykernel package"
 )
@@ -193,6 +217,10 @@ class TestInternalIPKernel(unittest.TestCase):
         sockets = self.objects_of_type(zmq.Socket)
         self.assertTrue(all(socket.closed for socket in sockets))
 
+    @unittest.skipIf(
+        sys.platform == "win32" and sys.version_info[:2] == (3, 8),
+        "xref: enthought/envisage#463"
+    )
     def test_ipykernel_live_objects(self):
         # Check that all IPython-related objects have been cleaned up
         # as expected.
@@ -269,7 +297,7 @@ class TestInternalIPKernel(unittest.TestCase):
         Find and return a list of all currently tracked instances of the
         given type.
         """
-        return [obj for obj in gc.get_objects() if isinstance(obj, type)]
+        return [obj for obj in gc.get_objects() if safe_isinstance(obj, type)]
 
     def create_and_destroy_kernel(self):
         """
