@@ -1,3 +1,12 @@
+# (C) Copyright 2007-2022 Enthought, Inc., Austin, TX
+# All rights reserved.
+#
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
+#
+# Thanks for using Enthought open source!
 """ The resource manager interface. """
 
 
@@ -5,7 +14,7 @@
 from traits.api import Instance, Interface
 
 # Local imports.
-from i_resource_protocol import IResourceProtocol
+from .i_resource_protocol import IResourceProtocol
 
 
 class IResourceManager(Interface):
@@ -24,5 +33,3 @@ class IResourceManager(Interface):
           manager.file('pkgfile://acme.ui.workbench/preferences.ini')
 
         """
-
-#### EOF ######################################################################
