@@ -1,10 +1,11 @@
-# (C) Copyright 2007-2019 Enthought, Inc., Austin, TX
+# (C) Copyright 2007-2022 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
-# license included in LICENSE.txt and may be redistributed only
-# under the conditions described in the aforementioned license.  The license
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
 # is also available online at http://www.enthought.com/licenses/BSD.txt
+#
 # Thanks for using Enthought open source!
 """ The default resource manager. """
 
@@ -42,9 +43,9 @@ class ResourceManager(HasTraits):
         from .package_resource_protocol import PackageResourceProtocol
 
         resource_protocols = {
-            'file'    : FileResourceProtocol(),
-            'http'    : HTTPResourceProtocol(),
-            'pkgfile' : PackageResourceProtocol()
+            "file": FileResourceProtocol(),
+            "http": HTTPResourceProtocol(),
+            "pkgfile": PackageResourceProtocol(),
         }
 
         return resource_protocols
@@ -54,12 +55,10 @@ class ResourceManager(HasTraits):
     def file(self, url):
         """ Return a readable file-like object for the specified url. """
 
-        protocol_name, address = url.split('://')
+        protocol_name, address = url.split("://")
 
         protocol = self.resource_protocols.get(protocol_name)
         if protocol is None:
-            raise ValueError('unknown protocol in URL %s' % url)
+            raise ValueError("unknown protocol in URL %s" % url)
 
         return protocol.file(address)
-
-#### EOF ######################################################################
