@@ -1,3 +1,12 @@
+# (C) Copyright 2007-2022 Enthought, Inc., Austin, TX
+# All rights reserved.
+#
+# This software is provided without warranty under the terms of the BSD
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
+# is also available online at http://www.enthought.com/licenses/BSD.txt
+#
+# Thanks for using Enthought open source!
 """ The *definition* of an action in a tool bar or menu. """
 
 
@@ -5,7 +14,7 @@
 from traits.api import Str
 
 # Local imports.
-from location import Location
+from .location import Location
 
 
 class Action(Location):
@@ -26,8 +35,6 @@ class Action(Location):
     def __str__(self):
         """ Return the 'informal' string representation of the object. """
 
-        return 'Action(%s)' % self.name
+        return "Action(%s)" % self.name
 
     __repr__ = __str__
-
-#### EOF ######################################################################
