@@ -1,10 +1,11 @@
-# (C) Copyright 2007-2019 Enthought, Inc., Austin, TX
+# (C) Copyright 2007-2022 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
-# license included in LICENSE.txt and may be redistributed only
-# under the conditions described in the aforementioned license.  The license
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
 # is also available online at http://www.enthought.com/licenses/BSD.txt
+#
 # Thanks for using Enthought open source!
 
 # Enthought library imports.
@@ -12,20 +13,17 @@ from pyface.image_resource import ImageResource
 from pyface.tasks.api import TaskWindow as PyfaceTaskWindow
 from traits.api import Instance, Property
 
-# Local imports.
-from envisage._compat import unicode_str
-
 
 class TaskWindow(PyfaceTaskWindow):
     """ A TaskWindow for use with the Envisage Tasks plugin.
     """
 
-    # The application that created and is managing this window.
-    application = Instance('envisage.ui.tasks.api.TasksApplication')
+    #: The application that created and is managing this window.
+    application = Instance("envisage.ui.tasks.api.TasksApplication")
 
-    # The window's icon.  We override it so it can delegate to the application
-    # icon if the window's icon is not set.
-    icon = Property(Instance(ImageResource), depends_on='_icon')
+    #: The window's icon.  We override it so it can delegate to the application
+    #: icon if the window's icon is not set.
+    icon = Property(Instance(ImageResource), observe="_icon")
 
     #### Protected interface ##################################################
 
@@ -44,7 +42,7 @@ class TaskWindow(PyfaceTaskWindow):
 
         title = self.active_task.name
         if self.application.name:
-            form = unicode_str('%s - %s')
+            form = "%s - %s"
             title = form % (title, self.application.name)
         return title
 
