@@ -1,4 +1,4 @@
-# (C) Copyright 2007-2021 Enthought, Inc., Austin, TX
+# (C) Copyright 2007-2022 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -440,6 +440,16 @@ class TasksApplication(Application):
         else:
             logger.debug("Application state successfully saved")
 
+    def _initialize_application_home(self):
+        """ Initialize the application directories.
+        """
+        # Extend the base class method to ensure the state directory exists.
+        super()._initialize_application_home()
+
+        state_location = os.path.join(self.home, "tasks", ETSConfig.toolkit)
+        logger.debug(f"Creating folder for tasks state: {state_location}")
+        os.makedirs(state_location, mode=0o700, exist_ok=True)
+
     #### Trait initializers ###################################################
 
     def _window_factory_default(self):
@@ -461,12 +471,7 @@ class TasksApplication(Application):
         return GUI(splash_screen=self.splash_screen)
 
     def _state_location_default(self):
-        state_location = os.path.join(
-            ETSConfig.application_home, "tasks", ETSConfig.toolkit
-        )
-        if not os.path.exists(state_location):
-            os.makedirs(state_location)
-
+        state_location = os.path.join(self.home, "tasks", ETSConfig.toolkit)
         logger.debug("Tasks state location is %s", state_location)
 
         return state_location
