@@ -1,10 +1,11 @@
-# (C) Copyright 2007-2019 Enthought, Inc., Austin, TX
+# (C) Copyright 2007-2022 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
-# license included in LICENSE.txt and may be redistributed only
-# under the conditions described in the aforementioned license.  The license
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
 # is also available online at http://www.enthought.com/licenses/BSD.txt
+#
 # Thanks for using Enthought open source!
 """ An extensible workbench window. """
 
@@ -36,10 +37,10 @@ class WorkbenchWindow(pyface.WorkbenchWindow):
     """ An extensible workbench window. """
 
     # Extension point Ids.
-    ACTION_SETS    = 'envisage.ui.workbench.action_sets'
-    VIEWS          = 'envisage.ui.workbench.views'
-    PERSPECTIVES   = 'envisage.ui.workbench.perspectives'
-    SERVICE_OFFERS = 'envisage.ui.workbench.service_offers'
+    ACTION_SETS = "envisage.ui.workbench.action_sets"
+    VIEWS = "envisage.ui.workbench.views"
+    PERSPECTIVES = "envisage.ui.workbench.perspectives"
+    SERVICE_OFFERS = "envisage.ui.workbench.service_offers"
 
     #### 'WorkbenchWindow' interface ##########################################
 
@@ -47,7 +48,7 @@ class WorkbenchWindow(pyface.WorkbenchWindow):
     #
     # This is equivalent to 'self.workbench.application', and is provided just
     # as a convenience since windows often want access to the application.
-    application = Delegate('workbench', modify=True)
+    application = Delegate("workbench", modify=True)
 
     # The action sets that provide the toolbars, menus groups and actions
     # used in the window.
@@ -102,7 +103,7 @@ class WorkbenchWindow(pyface.WorkbenchWindow):
     def _menu_bar_manager_default(self):
         """ Trait initializer. """
 
-        return self._action_manager_builder.create_menu_bar_manager('MenuBar')
+        return self._action_manager_builder.create_menu_bar_manager("MenuBar")
 
     def _status_bar_manager_default(self):
         """ Trait initializer. """
@@ -112,7 +113,7 @@ class WorkbenchWindow(pyface.WorkbenchWindow):
     def _tool_bar_managers_default(self):
         """ Trait initializer. """
 
-        return self._action_manager_builder.create_tool_bar_managers('ToolBar')
+        return self._action_manager_builder.create_tool_bar_managers("ToolBar")
 
     #### Trait change handlers ################################################
 
@@ -121,15 +122,11 @@ class WorkbenchWindow(pyface.WorkbenchWindow):
 
         self._service_ids = self._register_service_offers(self._service_offers)
 
-        return
-
     def _closed_changed(self):
         """ Static trait change handler. """
 
         self._unregister_service_offers(self._service_ids)
 
-        return
-
     ###########################################################################
     # 'pyface.WorkbenchWindow' interface.
     ###########################################################################
@@ -174,7 +171,7 @@ class WorkbenchWindow(pyface.WorkbenchWindow):
     # 'IServiceRegistry' interface.
     ###########################################################################
 
-    def get_service(self, protocol, query='', minimize='', maximize=''):
+    def get_service(self, protocol, query="", minimize="", maximize=""):
         """ Return at most one service that matches the specified query. """
 
         service = self.service_registry.get_service(
@@ -188,7 +185,7 @@ class WorkbenchWindow(pyface.WorkbenchWindow):
 
         return self.service_registry.get_service_properties(service_id)
 
-    def get_services(self, protocol, query='', minimize='', maximize=''):
+    def get_services(self, protocol, query="", minimize="", maximize=""):
         """ Return all services that match the specified query. """
 
         services = self.service_registry.get_services(
@@ -211,15 +208,11 @@ class WorkbenchWindow(pyface.WorkbenchWindow):
 
         self.service_registry.set_service_properties(service_id, properties)
 
-        return
-
     def unregister_service(self, service_id):
         """ Unregister a service. """
 
         self.service_registry.unregister_service(service_id)
 
-        return
-
     ###########################################################################
     # Private interface.
     ###########################################################################
@@ -244,12 +237,12 @@ class WorkbenchWindow(pyface.WorkbenchWindow):
         # Add the window to the service offer properties (this is so that it
         # is available to the factory when it is called to create the actual
         # service).
-        service_offer.properties['window'] = self
+        service_offer.properties["window"] = self
 
         service_id = self.register_service(
-            protocol   = service_offer.protocol,
-            obj        = service_offer.factory,
-            properties = service_offer.properties
+            protocol=service_offer.protocol,
+            obj=service_offer.factory,
+            properties=service_offer.properties,
         )
 
         return service_id
@@ -264,7 +257,3 @@ class WorkbenchWindow(pyface.WorkbenchWindow):
 
         for service_id in service_ids_copy:
             self.unregister_service(service_id)
-
-        return
-
-#### EOF ######################################################################
